#
# spec file for package irqbalance
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           irqbalance
Version:        1.4.0
Release:        150200.12.14.1
Summary:        Balance IRQs on SMP Machines
License:        GPL-2.0-or-later
Group:          System/Daemons
Url:            https://github.com/Irqbalance/irqbalance
Source:         https://github.com/Irqbalance/irqbalance/archive/v%{version}.tar.gz
Source3:        sysconfig.irqbalance
Patch1:         Set-fd-limit.patch
Patch2:         install-man-pages.patch
Patch3:         fix_buffer_overflow_compiler.patch
Patch4:         fix-ambiguous-parsing-of-node-entries-in-sys.patch
Patch5:         also-fetch-node-info-for-non-PCI-devices.patch
Patch6:         procinterrupts-check-xen-dyn-event-more-flexible.patch
Patch7:         remove-unused-path-in-check_for_irq_ban.patch
# Patch8 fixes Patch7
Patch8:         Update-classify.c.patch
Patch9:         irqbalance-properly-check-if-irq-is-banned.patch
# Patch10 fixes Patch9
Patch10:        Fix-uninitialized-variable.patch
Patch11:        fix_version_1_4_0
BuildRequires:  libcap-ng-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(glib-2.0)
Requires(pre):  coreutils
Requires(pre):  fillup
ExcludeArch:    s390 s390x
%{?systemd_requires}
%ifnarch %{arm}
BuildRequires:  libnuma-devel
%endif

%description
irqbalance dynamically switches the CPUs for IRQs to prevent cpu0 from
being used for all IRQs.

%prep
%setup -q
%autopatch -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure
make %{?_smp_mflags} LDFLAGS="-Wl,-z,relro,-z,now" CFLAGS="%{optflags} -fPIE -pie $(ncurses6-config --cflags)" LDFLAGS="$(ncurses6-config --libs)"
cp %{SOURCE3} .

%install
%make_install

mkdir -p %{buildroot}%{_fillupdir}/
install -m 0644 sysconfig.irqbalance %{buildroot}%{_fillupdir}/
sed -ie "s|EnvironmentFile=.*|EnvironmentFile=%{_sysconfdir}/sysconfig/irqbalance|g" misc/irqbalance.service
# Remove syslog.target in systemd service file; not provided by systemd anymore
sed -ie "s|After=syslog.target||g" misc/irqbalance.service
install -D -m 0644 misc/irqbalance.service %{buildroot}%{_unitdir}/irqbalance.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcirqbalance

%pre
%service_add_pre irqbalance.service

%post
%fillup_only %{name}
%service_add_post irqbalance.service

%preun
%service_del_preun irqbalance.service

%postun
%service_del_postun irqbalance.service

%files
%{_sbindir}/irqbalance
%{_sbindir}/irqbalance-ui
%{_sbindir}/rcirqbalance
%{_unitdir}/irqbalance.service
%{_mandir}/man1/irqbalance.1%{?ext_man}
%{_fillupdir}/sysconfig.irqbalance

%changelog
* Mon Mar 13 2023 trenn@suse.de
- Last changes log was wrong, this part has been added to SP4
  changes but were missing in SP2/SP3 and are added now (bsc#1208717):
  Fix segfault from previous update (bsc#1206668)
  A Fix-uninitialized-variable.patch
* Wed Nov 23 2022 trenn@suse.de
- Fix segfault from previous update (bsc#1206668)
- Fix version - Maintainer forgot to increase version to 1.4.0
  A fix_version_1_4_0
- Add mainline fixes (bnc#1204961):
  The first 2 patches are cleanup patches which should not have any
  functional change, but make life easier to backport the real fix.
  All patches are mainline:
  A    Update-classify.c.patch
  A    irqbalance-properly-check-if-irq-is-banned.patch
  A    remove-unused-path-in-check_for_irq_ban.patch
* Thu Apr  1 2021 trenn@suse.de
- not balancing interrupts in Xen guests (bsc#1178477, bsc#1183405)
  A procinterrupts-check-xen-dyn-event-more-flexible.patch
* Fri Mar 12 2021 shung-hsi.yu@suse.com
- Adapt also-fetch-node-info-for-non-PCI-devices.patch to v1.4.0, and
  backport process_one_line() and get_int() which is required for it
  to work.
* Tue Mar  9 2021 shung-hsi.yu@suse.com
- Correctly detect the NUMA node of non-PCI devices.
  (bsc#1156315 bsc#1183157)
- add also-fetch-node-info-for-non-PCI-devices.patch
* Thu Mar  4 2021 shung-hsi.yu@suse.com
- Due to a bug in irqbalance's parsing of /sys/devices/system/cpu/cpu*/node*
  entries, all CPUs is considered to be on NUMA node 0. Backport fix for
  ambiguous parsing of *node* entries in /sys from upstream to fix this issue.
  (bsc#1156315, bsc#1182254)
- add fix-ambiguous-parsing-of-node-entries-in-sys.patch
* Thu Nov 14 2019 ohering@suse.de
- Revert previous changes for kernel 5.3+
- remove 0001-Revert-remove-affinity_hint-infrastructure.patch
- remove set-numa-node.patch
- remove 0001-Revert-Types-clean-out-unused-variables-from-irq_inf.patch
* Fri Oct 25 2019 ohering@suse.de
- In HyperV VMs all NVME MSI interrupts are set to unmanaged to
  compensate the lack of matrix.c in pre-v4.20 kernels.
  Irqbalanced is supposed to spread the load. (bsc#1119461, bsc#1154905, bsc#1138190)
  Performance can be improved further with --hintpolicy=subset
- add 0001-Revert-remove-affinity_hint-infrastructure.patch
- add set-numa-node.patch
- add 0001-Revert-Types-clean-out-unused-variables-from-irq_inf.patch
* Thu Oct  4 2018 trenn@suse.de
- Allow compilation with SLE-12 and before by:
  * removing -std=C99 Latest compiler version does not complain
  anymore, SLE12 SPx and before did.
  * Fix a possible buffer overflow compiler warning
  A fix_buffer_overflow_compiler.patch
* Mon Oct  1 2018 egotthold@suse.com
- Removed aarch64-compile-fixes.patch because it is mainline now.
- Update to version 1.4.0:
  * Fixed an erroneous calculation of min_load that restricted candidates to a
    subset of objects
  * Fixed powerpc hotplug detection
  * Cleaned up syslog target dependency
  * Added some self test infrastructure (via make check)
- Update to version 1.3.0
  * New features in this release:
    optimization of platform device irq detection
    Added sample udev rules to trigger irq rescans on device add/remove
    Made irqbalance ui an optional compile component
    Added support for Intel CoD
    Add -v | --version option to command line
  * Bug fixes in this release:
    Misc compiler warning fixes and spelling errors
    Compilation error fix on aarch64
    Compilation error fix when using clang in c99 mode
    Unused variable cleanup
    Lots of memory leak cleanup in irqbalance-ui
    Prevent irqbalance from running in a container
    Fix irq affinity assignment in some cases to wrong numa node
    Fix oneshot mode
    exclude legacy irq 255
  * Deprecations:
    without-glib2 is removed, we just need it enough that we can't dummy it up
    anymore
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Mar  1 2017 fschnizlein@suse.com
- Remove superfluous comment out man package packing
* Mon Feb  6 2017 dimstar@opensuse.org
- Switch to ncurses6: use ncurses6-config to find the correct
  CFLAGS and libraries (boo#1021328).
* Thu Jan 12 2017 dmueller@suse.com
- update to 1.2.0:
  * sort_irq logic rework to fix unintended ordering
  * removal of the affinity_hint infrastructure as its not needed
  * fixes for invalid cpumask parsing
  * many other minior fixes (see git log)
  * Aarch64 support
  * live interactive monitoring of irqbalance and live adjustment with irqbalance-ui
- remove fix-aarch64-support.patch: upstreamed
- add install-man-pages.patch
- add aarch64-compile-fixes.patch
* Fri Oct 14 2016 msuchanek@suse.com
- Set-fd-limit.patch: Increase limit on file descriptors (bsc#998399) (fate#321645)
* Tue Feb 23 2016 schwab@suse.de
- fix-aarch64-support.patch: Fix AArch64 support
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 1.1.0
  * Banning support fixes
  * Load calculation improvements
  * Documentation fixes
  * Fix command line preservation across re-scan
  * Memory leak fixes
  * Misc. bug fixes
  * ARM irq support
  * New --banmod option
  * New sleep interval option
* Wed Nov 18 2015 mbrugger@suse.com
- Only exclude arch s390 and s390x
* Tue Nov 17 2015 mbrugger@suse.com
- enable build for aarch64
* Mon Nov  9 2015 dmueller@suse.com
- enable build for %%arm
* Mon Mar 16 2015 mpluskal@suse.com
- Clenup spec file with spec-cleaner
- Remove bug-893478_warn-once.patch
- Update to 1.0.9
  * PCI quirk support
  * System Logging compatibility
  * isolcpus inheritance
  * Misc. Bugfixes
* Fri Jan 23 2015 p.drouand@gmail.com
- Update to version 1.0.8
  * No ChangeLog available
- Fix home page and download source Url
- Update bug-893478_warn-once.patch; (submitted and accepted to/by
  upstream)
* Thu Sep 11 2014 trenn@suse.de
- Only warn once for affinity hint subset empty irqs (bnc#893478)
  * Add bug-893478_warn-once.patch
- Rename rcirq_balancer like the package name and the already renamed
  systemd service: rcirqbalance
* Mon Jun 16 2014 trenn@suse.de
- Change non-existing group: System/Environment/Daemons to System/Daemons
* Fri Jun 13 2014 trenn@suse.de
- Really fillup (and create) /etc/sysconfig/irqbalance file
- Remove IRQBALANCE_ONESHOT variable from sysconfig file.
  Default IRQBALANCE_ONESHOT=auto will be interpreted as --oneshot, other
  than documented in /etc/sysconfig/irqbalance. The same can be achieved via
  passing --oneshot via newly introduced IRQBALANCE_ARGS= variable (see below)
  bnc#874125
- The irqbalance.service file passes $IRQBALANCE_ARGS when the daemon
  is started. Provide it for the user via /etc/sysconfig/irqbalance.
* Wed Dec 11 2013 dvaleev@suse.com
- enable ppc64le
* Sun Oct 20 2013 p.drouand@gmail.com
- Update to version 1.0.7
  + No changelog available
- Drop sysvinit support as no target systems use it anymore
- Keep rcirq_balancer, make it symlink to /usr/sbin/service
- Remove syslog.target in irqbalance.service
  Please see http://lists.opensuse.org/archive/opensuse-packaging/2013-05/msg00102.html
- Change Group for valid one
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Nov 22 2012 rmilasan@suse.com
- Ensure that EnvironmentFile from irqbalance.service points to
  /etc/sysconfig/irqbalance environment config file.
* Thu Sep  6 2012 trenn@suse.de
- Update to version 1.0.4:
  New release of irqbalance, several minor cleanups and a few
  significant bug fixes and feature enhancements:
  - Fixed a divide by zero bug
  - Fixed a memory corruptor when items are not assigned to a specfic numa node
  - Added a banscript option, that allows a user defined script to be run to
    determine if a given irq should be excluded from balancing
  - Improve rescan ability to catch a timing race early in irqbalance setup
  - Added ability to force irqbalance to rescan irqs on reception of a SIGHUP.
  - Force affinity settings even if manually overridden outside of irqbalance.
  - Added a --foreground option to force foreground execution without debug output
* Mon Jun 25 2012 trenn@suse.de
- Correct bogus /etc/sysconfig/irqbalance comment:
  Service is started as daemon by default, on single and multi core
  systems
* Wed May  9 2012 trenn@suse.de
- Update to version 1.0.3 and make spec file to spec-cleaner clean.
* Thu Dec  1 2011 coolo@suse.com
- make it as exclusive as numactl
* Tue Nov 29 2011 crrodriguez@opensuse.org
- Use systemd macros in pre/post scripts
* Mon Oct 17 2011 trenn@suse.de
- Update to version 1.0
  - Remove files that are upstream: manpage, systemd config file
  - Introduction of highest topology level: Numa node
  - ...
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Aug 16 2011 saschpe@suse.de
- Run spec-cleaner on spec file
- Don't start irqbalance by default, testing confirmed that it does
  not make any difference on machines with less than 32 cores
  nowadays (GKH's comment)
* Tue Jun  7 2011 aj@suse.de
- Add systemd service file.
* Sun Nov  7 2010 cristian.rodriguez@opensuse.org
- This is a long running service, use full RELRO here.
* Sat Oct  2 2010 cristian.rodriguez@opensuse.org
- update to version 0.56 in order to get libcap-ng support
  so irqbalance can drop privileges.
* Wed Jun 17 2009 crrodriguez@suse.de
- fix build when as-needed is a default linker option
* Wed Nov  5 2008 bwalle@suse.de
- Don't start the irqbalance on IA64 SGI SN2 systems (bnc#441505).
* Fri Aug 15 2008 bwalle@suse.de
- add "Required-Stop" to fix rpmlint error
* Tue Dec 11 2007 bwalle@suse.de
- add /etc/sysconfig/irqbalance configuration file for
  IRQBALANCE_ONESHOT, IRQBALANCE_BANNED_CPUS and
  IRQBALANCE_BANNED_INTERRUPTS configuration (#342593)
- fix some minor rpmlint warnings
* Thu Apr 26 2007 bwalle@suse.de
- remove special handling of timer interrupt and dual core
  systems from init script because the new irq balancer does
  that automatically
* Sun Apr 15 2007 bwalle@suse.de
- wrote manpage for irqbalance
* Wed Apr 11 2007 bwalle@suse.de
- updated to irqbalance.org 0.55
  o rewrite from static arrays to dynamic lists using glib
  o added IRQBALANCE_ONESHOT, IRQBALANCE_BANNED_INTERRUPTS
    IRQBALANCE_BANNED_CPUS configuration environment variables
- changed init script to not balance the timer interrupt due to
  broken hardware
- added $remote_fs to Required-Start since the binary needs
  glib2
* Tue Apr  3 2007 bwalle@suse.de
- increased IRQ number to (256 + (32*MAX_CPU)) as done in the
  x86_64 kernel
* Fri Jul 14 2006 sf@suse.de
- added patch from bug #171500, fixing regexps
* Tue May 16 2006 sf@suse.de
- added irqbalance-assert.diff to completely fix
  bug #158186 (see changelog entry below)
* Tue May  9 2006 sf@suse.de
- increase MAX_INTERRUPTS  to 512 to avoid
  segfault (bug #158186)
* Wed May  3 2006 sf@suse.de
- modified startscript to start irqbalancing only on real SMP
  machines (multisocket) (bug #171500)
* Wed Feb  8 2006 ak@suse.de
- increase max number of cpus to 128 (#146945)
- install manpage
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Fri Sep  2 2005 ro@suse.de
- rcscript: ignore on machines with < 2 CPUs
* Mon Jun 20 2005 ro@suse.de
- build with fPIE/pie
* Mon Feb 16 2004 sf@suse.de
- update to 0.09
* Sat Sep 20 2003 kukuk@suse.de
- Add PreRequires for insserv
* Thu Sep  4 2003 ro@suse.de
- added stop_on_removal and restart_on_update
- changed insserv_and_fillup to insserv_force_if_yast
* Thu Sep  4 2003 sf@suse.de
- added %%insserv_and_fillup in %%post
  and %%insserv_cleanup in %%postun
* Thu Sep  4 2003 ak@suse.de
- update to version 0.6
- Clean up init script a bit
- Move initscript outside tar and mark as source
* Fri Mar 21 2003 sf@suse.de
- initial version 0.1
